CCL: Core Cosmology Library

CCL

Core Cosmology Library

The Core Cosmology Library (CCL) provides routines to compute basic cosmological observables with validated numerical accuracy. In the current version, predictions are provided for distances and background quantities, an gular auto- and cross-spectra of cosmic shear and clustering, correlation functions and the halo mass function. Fiducial specifications for the expected LSST galaxy distributions and clustering bias are also included, together with a facility to compute redshift distributions for a user-defined photometric redshift model. CCL is written in C with a Python interface.

# Installation

For installation instructions, see the README file.

# Contribute

If you plan to contribute new features to CCL, please see our CONTRIBUTE file for instructions.

# License

CCL is released under the license provided in the LICENSE file.

# Repository

For the latest version of CCL, please visit the github repository: https://github.com/LSSTDESC/CCL